@@ -30,13 +30,13 @@ sub setup_installer
 
     my @build_files  = grep { $_->name eq 'Makefile.PL' or $_->name eq 'Build.PL' } @{ $self->zilla->files };
 
-    $self->log_fatal('No Makefile.PL or Build.PL was found. [=' . __PACKAGE__ . '] should appear in dist.ini after your installer!')
+    $self->log_fatal('No Makefile.PL or Build.PL was found. [=' . __PACKAGE__ . '] should appear in dist.ini after your installer plugin(s)!')
         unless @build_files;
 
     foreach my $file (@build_files)
     {
         my $content = 'use File::Which;' . "\n"
-            . 'do { print "' . $self->executable . ' not found; aborting.\\n"; ' . 'exit 0 } if not which("' . $self->executable . '");' . "\n";
+            . 'die "' . $self->executable . ' not found; aborting" if not which("' . $self->executable . '");' . "\n";
         $file->content( $content . $file->content );
     }
     return;
